//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;


namespace MindFusion.Scheduling.WinForms.Samples.CS.Tutorial4
{
	/// <summary>
	/// Summary description for MyApp.
	/// </summary>
	public class MyApp : Appointment
	{
		public MyApp()
		{
			kept = true;
		}

		public override void SaveTo(System.IO.BinaryWriter writer, BinarySerializationContext context)
		{
			base.SaveTo(writer, context);

			context.WriteBool(kept, writer);
		}

		public override void LoadFrom(System.IO.BinaryReader reader, BinarySerializationContext context)
		{
			base.LoadFrom(reader, context);

			kept = context.ReadBool(reader);
		}

		protected override void CopyOccurrence(Item master)
		{
			base.CopyOccurrence(master);

			kept = (master as MyApp).Kept;
		}

		protected override ItemState CreateState()
		{
			return new MyAppState();
		}

		protected override ItemState SaveState()
		{
			MyAppState state = base.SaveState() as MyAppState;
			state.Kept = this.Kept;
			return state;
		}

		protected override void RestoreState(ItemState state)
		{
			MyAppState myState = state as MyAppState;
			this.Kept = myState.Kept;
			base.RestoreState(state);
		}


		public bool Kept
		{
			get { return kept; }
			set
			{
				kept = value;

				if (Recurrence != null)
					Recurrence.MarkException(this, false);
			}
		}


		private bool kept;
	}

	public class MyAppState : ItemState
	{
		public override bool Equals(ItemState other)
		{
			MyAppState state = other as MyAppState;
			if (state == null)
				return false;

			if (Kept != state.Kept)
				return false;

			return base.Equals(other);
		}


		public bool Kept
		{
			get { return kept; }
			set { kept = value; }
		}


		private bool kept;
	}
}
