//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;


namespace MindFusion.Scheduling.WinForms.Samples.CS.Tutorial5
{
	/// <summary>
	/// Summary description for MyAppViewer.
	/// </summary>
	public class MyAppViewer : IItemViewer
	{
		public virtual void Draw(ItemDrawContext context)
		{
			Rectangle b = context.Bounds;
			MindFusion.Drawing.IGraphics g = context.Graphics;
			Style s = context.Style;
			Brush headerBrush = new SolidBrush(s.HeaderTextColor);
			Pen strokePen = new Pen(Color.Red, 2);
			MyApp item = context.Item as MyApp;

			// If the item is selected, draw a faint background
			if (context.Calendar.ItemSelection.Contains(item))
				g.FillRectangle(Brushes.PaleGoldenrod, b);

			// Draw the item's text
			g.DrawString(context.Item.HeaderText, context.Style.HeaderFont,
				headerBrush, new RectangleF(b.Left, b.Top, b.Width, b.Height));

			// Stroke the text if the appointment is not kept
			if (!item.Kept)
			{
				int width = (int)Math.Ceiling(
					g.MeasureString(context.Item.HeaderText, context.Style.HeaderFont, b.Width).Width);
				g.DrawLine(strokePen,
					b.Left, b.Top + b.Height / 2,
					b.Left + width, b.Top + b.Height / 2);
			}

			strokePen.Dispose();
			headerBrush.Dispose();
		}
	}
}
